@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2011 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2014 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: DemoSpace.h,v 1.13 2011/01/09 01:59:31 bowkenken Exp $
+* $Id: DemoSpace.h,v 1.15 2014/01/07 23:44:46 bowkenken Exp $
 ***************************************************************/
 
 #ifndef DEMO_SPACE_H
@@ -111,6 +111,12 @@ private:
 	GtkStyle *pStyle;
 #endif // D_GTK
 	
+#ifdef D_MAC
+	// եȤΥ
+//@@@
+	void *pStyle;
+#endif // D_MAC
+	
 #ifdef D_IPHONE
 	// եȤΥ
 //@@@
