@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2011 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2014 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: DemoTitle.cpp,v 1.20 2011/01/09 01:59:31 bowkenken Exp $
+* $Id: DemoTitle.cpp,v 1.22 2014/01/07 23:55:39 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -164,6 +164,16 @@ void DemoTitle::init()
 	gtk_style_set_font( pTitleStyle, gdk_fontset_load( sFontName ) );
 #endif // D_GTK
 
+#ifdef D_MAC
+	// ǥեȤΥ
+
+	if( pTitleStyle == NULL )
+		pTitleStyle = (void *)1;
+
+	// եȤ
+
+#endif // D_MAC
+
 #ifdef D_IPHONE
 	// ǥեȤΥ
 
@@ -228,6 +238,11 @@ void DemoTitle::initAnime()
 	h = gMapDrawingArea->allocation.height;
 #endif // D_GTK
 
+#ifdef D_MAC
+	w = gMainMapView.visibleRect.size.width;
+	h = gMainMapView.visibleRect.size.height;
+#endif // D_MAC
+
 #ifdef D_IPHONE
 	w = gMainMapWin.mapScrollView.frame.size.width;
 	h = gMainMapWin.mapScrollView.frame.size.height;
@@ -276,6 +291,9 @@ bool DemoTitle::draw()
 			gMapDrawingArea->allocation.height );
 #endif // D_GTK
 
+#ifdef D_MAC
+#endif // D_MAC
+
 #ifdef D_IPHONE
 	CGContextRef context = gPcgDun.getWBuf()->getPixMap();
 	CGRect rect = gMainMapWin.mapScrollView.bounds;
@@ -338,6 +356,10 @@ bool DemoTitle::draw()
 
 	frame++;
 
+#ifdef D_MAC
+	[gMainMapView setNeedsDisplay];
+#endif // D_MAC
+	
 #ifdef D_IPHONE
 	[gMainMapWin.view setNeedsDisplay];
 	[gMainMapWin.mapView setNeedsDisplay];
@@ -770,6 +792,10 @@ void DemoTitle::drawTitleChar(
 	gdk_draw_string( d, font, gc, x, y, str );
 #endif // D_GTK
 
+#ifdef D_MAC
+//@@@
+#endif // D_MAC
+
 #ifdef D_IPHONE
 	CGContextRef context = gPcgDun.getWBuf()->getPixMap();
 
