@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2011 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2014 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: FileList.h,v 1.28 2011/01/09 01:59:31 bowkenken Exp $
+* $Id: FileList.h,v 1.31 2014/03/15 01:49:46 bowkenken Exp $
 ***************************************************************/
 
 #ifndef FILE_LIST_H
@@ -38,7 +38,10 @@
 #include <stdlib.h>
 #include <stdio.h>
 
-#if defined( D_WS ) || defined( D_GTK ) || defined( D_IPHONE )
+#if defined( D_WS ) \
+	|| defined( D_GTK ) \
+	|| defined( D_MAC) \
+	|| defined( D_IPHONE )
 # include <dirent.h>
 # include <sys/stat.h>
 #endif
@@ -51,6 +54,10 @@
 # include "GtkWSCstring.h"
 #endif // D_GTK
 
+#ifdef D_MAC
+# include "MacWSCstring.h"
+#endif // D_MAC
+
 #ifdef D_IPHONE
 # include "IPhoneWSCstring.h"
 #endif // D_IPHONE
@@ -66,7 +73,12 @@
 // ޤǡΤܤ
 ////////////////////////////////////////////////////////////////
 
-#define	STR_DIR_BASE	".lnl/xlnl/"
+#if	defined( D_DOS ) || defined( D_MFC )
+# define	STR_DIR_BASE	"_lnl/xlnl/"
+#else
+# define	STR_DIR_BASE	".lnl/xlnl/"
+#endif
+
 #define	STR_DIR_BASE_GRAPH	STR_DIR_BASE "graph/"
 
 static WSCstring sDirBaseSelGraph = "default/";
