@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2011 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2014 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GameSound.cpp,v 1.11 2011/01/09 01:59:31 bowkenken Exp $
+* $Id: GameSound.cpp,v 1.13 2014/01/07 23:55:39 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -114,6 +114,12 @@ GameSound::GameSound()
 	lsItemUse.next = NULL;
 	lsItemOpen.next = NULL;
 	lsItemSmoke.next = NULL;
+
+	lsActionAppear.next = NULL;
+	lsActionTeleportRecall.next = NULL;
+	lsActionTeleportParty.next = NULL;
+	lsActionTeleportShort.next = NULL;
+	lsActionTeleportLong.next = NULL;
 #endif
 }
 
@@ -240,7 +246,7 @@ void GameSound::init()
 	initLsSound( &lsStairsDown,
 			"stairs/down/" );
 	initLsSound( &lsStairsUp,
-			"stairs/up/cursor11.wav" );
+			"stairs/up/" );
 
 	initLsSound( &lsItemUse,
 			"item/use/" );
@@ -248,6 +254,17 @@ void GameSound::init()
 			"item/open/" );
 	initLsSound( &lsItemSmoke,
 			"item/smoke/" );
+
+	initLsSound( &lsActionAppear,
+			"action/appear/" );
+	initLsSound( &lsActionTeleportRecall,
+			"action/teleport/recall/" );
+	initLsSound( &lsActionTeleportParty,
+			"action/teleport/party/" );
+	initLsSound( &lsActionTeleportShort,
+			"action/teleport/short/" );
+	initLsSound( &lsActionTeleportLong,
+			"action/teleport/long/" );
 #endif
 
 	// 
@@ -382,6 +399,12 @@ void GameSound::freeAll()
 	freeLsSound( &lsItemUse );
 	freeLsSound( &lsItemOpen );
 	freeLsSound( &lsItemSmoke );
+
+	freeLsSound( &lsActionAppear );
+	freeLsSound( &lsActionTeleportRecall );
+	freeLsSound( &lsActionTeleportParty );
+	freeLsSound( &lsActionTeleportShort );
+	freeLsSound( &lsActionTeleportLong );
 #endif
 }
 
@@ -599,6 +622,22 @@ void GameSound::play( sound_kind_t kind, long nRepeat )
 		playRandm( lsItemSmoke.next, nRepeat );
 		break;
 
+	case SOUND_KIND_ACTION_APPEAR:
+		playRandm( lsActionAppear.next, nRepeat );
+		break;
+	case SOUND_KIND_ACTION_TELEPORT_RECALL:
+		playRandm( lsActionTeleportRecall.next, nRepeat );
+		break;
+	case SOUND_KIND_ACTION_TELEPORT_PARTY:
+		playRandm( lsActionTeleportParty.next, nRepeat );
+		break;
+	case SOUND_KIND_ACTION_TELEPORT_SHORT:
+		playRandm( lsActionTeleportShort.next, nRepeat );
+		break;
+	case SOUND_KIND_ACTION_TELEPORT_LONG:
+		playRandm( lsActionTeleportLong.next, nRepeat );
+		break;
+
 	case SOUND_KIND_MAX_N:
 		break;
 	}
