@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2011 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2014 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GameSound.h,v 1.10 2011/01/09 01:59:31 bowkenken Exp $
+* $Id: GameSound.h,v 1.12 2014/01/07 23:44:46 bowkenken Exp $
 ***************************************************************/
 
 #ifndef GAME_SOUND_H
@@ -136,6 +136,12 @@ private:
 	LsSound lsItemOpen;
 	LsSound lsItemSmoke;
 
+	LsSound lsActionAppear;
+	LsSound lsActionTeleportRecall;
+	LsSound lsActionTeleportParty;
+	LsSound lsActionTeleportShort;
+	LsSound lsActionTeleportLong;
+
 public:
 	GameSound();
 	~GameSound();
