@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2011 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2014 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GlobalVar.h,v 1.40 2011/01/09 01:59:31 bowkenken Exp $
+* $Id: GlobalVar.h,v 1.44 2014/02/02 17:49:46 bowkenken Exp $
 ***************************************************************/
 
 #ifndef GLOBAL_VAR_H
@@ -85,6 +85,12 @@ typedef long GtkButton;
 # include "GuiStat.h"
 #endif // D_GTK
 
+#ifdef D_MAC
+# import "xlnl_macAppDelegate.h"
+# include "main-mac.h"
+# include "GuiStat.h"
+#endif // D_MAC
+
 #ifdef D_IPHONE
 # include "main-iphone.h"
 # include "GuiStat.h"
@@ -186,6 +192,14 @@ extern GtkWidget *gMapVScrollBar;
 extern GuiStat gGuiStat;
 #endif // D_GTK
 
+#ifdef D_MAC
+extern NSLock *gMainLock;
+extern MacMain *gMacMain;
+extern NSWindow *gMainWindow;
+extern NSScrollView *gMainMapScrollView;
+extern MacMapView *gMainMapView;
+#endif // D_MAC
+
 #ifdef D_IPHONE
 extern NSLock *gMainLock;
 extern UIWindow *gMainWindow;
@@ -199,4 +213,6 @@ extern bool gFlagExit;
 extern CDir3d g_Dir3d;
 #endif // D_MFC
 
+void check_memory_GlobalVar_cpp();
+
 #endif /* GLOBAL_VAR_H */
