@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2011 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2014 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GtkWSDimage.h,v 1.8 2011/01/09 01:59:31 bowkenken Exp $
+* $Id: GtkWSDimage.h,v 1.10 2014/01/07 23:44:46 bowkenken Exp $
 ***************************************************************/
 
 #ifndef GTK_WSD_IMAGE_DEV_H
@@ -50,7 +50,7 @@ public:
 	}
 	void destroyImage()
 	{
-		gdk_pixbuf_unref( pPixbuf );
+		g_object_unref( pPixbuf );
 	}
 
 	GdkPixbuf *getPixbuf()
