@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2011 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2014 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiMenu.h,v 1.26 2011/01/09 01:59:31 bowkenken Exp $
+* $Id: GuiMenu.h,v 1.28 2014/01/07 23:44:46 bowkenken Exp $
 ***************************************************************/
 
 #ifndef GUI_MENU_H
@@ -86,6 +86,11 @@ private:
 	GtkWidget *labelMenuPageN;
 #endif // D_GTK
 
+#ifdef D_MAC
+//@@@
+	void *aBtnMenu[MENU_MAX_N_PER_PAGE];
+#endif // D_MAC
+
 #ifdef D_IPHONE
 //@@@
 	void *aBtnMenu[MENU_MAX_N_PER_PAGE];
@@ -108,6 +113,11 @@ public:
 	gboolean bFlagEnter;
 #endif // D_GTK
 
+#ifdef D_MAC
+//@@@
+	void *mMenuWin;
+#endif // D_MAC
+
 #ifdef D_IPHONE
 //@@@
 	void *mMenuWin;
