@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2011 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2014 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiMisc.cpp,v 1.20 2011/01/09 01:59:31 bowkenken Exp $
+* $Id: GuiMisc.cpp,v 1.23 2014/01/07 23:55:39 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -37,6 +37,8 @@
 
 #include "GuiMisc.h"
 
+#define FLG_CHK_ALLOC_COLOR_MAP	0
+
 const int PEN_WIDTH_BOLD = 2;
 const int PEN_WIDTH_NORMAL = 1;
 
@@ -258,15 +260,20 @@ void CvColorRGB( GdkColor *color, int n )
 		return;
 	}
 
+#if FLG_CHK_ALLOC_COLOR_MAP
 	static bool flg_alloc_color_map[8] = {
 		false, false, false, false,
 		false, false, false, false,
 	};
 
-//	if( (map_n > -1) && !flg_alloc_color_map[map_n] ){
+	if( (map_n > -1) && !flg_alloc_color_map[map_n] ){
 		gdk_color_alloc( gdk_colormap_get_system(), color );
 		flg_alloc_color_map[map_n] = true;
-//	}
+	}
+#else //FLG_CHK_ALLOC_COLOR_MAP
+	if( map_n > -1 )
+		gdk_color_alloc( gdk_colormap_get_system(), color );
+#endif //FLG_CHK_ALLOC_COLOR_MAP
 }
 #endif // D_GTK
 
