@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2011 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2014 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiNum.cpp,v 1.33 2011/01/09 01:59:31 bowkenken Exp $
+* $Id: GuiNum.cpp,v 1.36 2014/01/07 23:55:39 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -609,6 +609,11 @@ void GuiNum::up_down_num_label( long n, long d )
 	gtk_label_get( lbl, &str );
 #endif // D_GTK
 
+#ifdef D_MAC
+//@@@
+	char *str = NULL;
+#endif // D_MAC
+
 #ifdef D_IPHONE
 //@@@
 	char *str = NULL;
@@ -635,7 +640,7 @@ void GuiNum::up_down_num_label( long n, long d )
 #endif // D_WS
 
 #ifdef D_GTK
-	//gtk_label_set_text( lbl, num );
+	gtk_label_set_text( lbl, num );
 
 	if( (c == '+') || (c == '-') )
 		gKey.setChar( KEY_MENU_NUM_SGN );
