@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2011 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2014 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiReplay.h,v 1.6 2011/01/09 01:59:31 bowkenken Exp $
+* $Id: GuiReplay.h,v 1.8 2014/01/07 23:44:46 bowkenken Exp $
 ***************************************************************/
 
 #ifndef GUI_REPLAY_H
@@ -72,6 +72,11 @@ public:
 	GtkWidget *mReplayWin;
 #endif // D_GTK
 
+#ifdef D_MAC
+//@@@
+	void *mReplayWin;
+#endif // D_MAC
+
 #ifdef D_IPHONE
 //@@@
 	void *mReplayWin;
