@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2011 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2014 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiSkillEdit.h,v 1.8 2011/01/09 01:59:31 bowkenken Exp $
+* $Id: GuiSkillEdit.h,v 1.10 2014/01/07 23:44:46 bowkenken Exp $
 ***************************************************************/
 
 #ifndef GUI_SKILL_EDIT_H
@@ -77,6 +77,11 @@ public:
 	GtkWidget *mSkillEditWin;
 #endif // D_GTK
 
+#ifdef D_MAC
+//@@@
+	void *mSkillEditWin;
+#endif // D_MAC
+
 #ifdef D_IPHONE
 //@@@
 	void *mSkillEditWin;
