@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2011 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2014 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiStat.h,v 1.18 2011/01/09 01:59:31 bowkenken Exp $
+* $Id: GuiStat.h,v 1.20 2014/01/07 23:44:46 bowkenken Exp $
 ***************************************************************/
 
 #ifndef GUI_STAT_H
@@ -41,6 +41,10 @@
 # include "party.h"
 #endif // D_GTK
 
+#ifdef D_MAC
+# include "MacWSCstring.h"
+#endif // D_MAC
+
 #ifdef D_IPHONE
 # include "IPhoneWSCstring.h"
 #endif // D_IPHONE
@@ -100,6 +104,11 @@ public:
 	GtkWidget *mStatWin;
 #endif // D_GTK
 
+#ifdef D_MAC
+//@@@
+	void *mStatWin;
+#endif // D_MAC
+
 #ifdef D_IPHONE
 //@@@
 	void *mStatWin;
