@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2011 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2014 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: MouseMap.cpp,v 1.46 2011/01/09 01:59:31 bowkenken Exp $
+* $Id: MouseMap.cpp,v 1.48 2014/01/07 23:55:39 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -506,7 +506,7 @@ void funcMotionClickLR(
 	else
 		return;
 
-	callFuncKey( KEY_N_MOUSE_P_CLICK( n ) );
+	callFuncKey( KEY_N_MOUSE_P_CLICK( fn ) );
 }
 
 ////////////////////////////////////////////////////////////////
