@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2011 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2014 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: Pcg.cpp,v 1.32 2011/01/09 01:59:31 bowkenken Exp $
+* $Id: Pcg.cpp,v 1.35 2014/01/07 23:55:39 bowkenken Exp $
 ***************************************************************/
 
 #include <time.h>
@@ -122,12 +122,105 @@ void Pcg::load( WSCstring path )
 		if( buf == NULL )
 			break;
 		pImage->setPixbuf( buf );
-		gdk_pixbuf_unref( oldBuf );
+		g_object_unref( oldBuf );
 
 		break;
 	} while( 0 );
 #endif // D_GTK
 
+#ifdef D_MAC
+#if 0
+	NSString *pathStr = [NSString stringWithUTF8String:(const char *)path];
+	CGImageRef buf = [[CGImage alloc] initWithContentsOfFile:pathStr];
+#elif 1
+	NSString *pathStr = [NSString stringWithUTF8String:(const char *)path];
+	NSImage *tmpUIImg = [[NSImage alloc] initWithContentsOfFile:pathStr];
+	CGImageRef tmpCGImg = [tmpUIImg CGImageForProposedRect:nil context:nil hints:nil];
+	
+	NSImage *buf = tmpUIImg;
+#elif 0
+	NSString *pathStr = [NSString stringWithUTF8String:(const char *)path];
+	NSImage *tmpUIImg = [[NSImage alloc] initWithContentsOfFile:pathStr];
+	CGImageRef tmpCGImg = tmpUIImg.CGImage;
+	
+	UIImage *buf = tmpUIImg;
+#else
+	NSString *pathStr = [NSString stringWithUTF8String:(const char *)path];
+	NSImage *tmpUIImg = [[NSImage alloc] initWithContentsOfFile:pathStr];
+
+	NSImage *buf = tmpUIImg;
+#endif
+
+	// Ѥοȴˤ
+
+#if 0
+//@@@
+	WSCstring ext = FileList::getExt( path );
+	do {
+		if( (ext != "bmp") && (ext != "BMP") )
+			break;
+
+		CGColorSpaceRef colorSpace = CGColorSpaceCreateDeviceRGB();
+
+		long w = CGImageGetWidth(tmpCGImg);
+		long h = CGImageGetHeight(tmpCGImg);
+		unsigned char *frameBuf = (unsigned char*)malloc(w * h * 4);
+
+		CGContextRef tmpContext = CGBitmapContextCreate(frameBuf, w, h, 8, w * 4, colorSpace, kCGImageAlphaPremultipliedLast);
+		CGContextDrawImage(tmpContext, CGRectMake(0, 0, w, h), tmpCGImg);
+		CGContextRelease(tmpContext);
+
+		CGColorSpaceRelease(colorSpace);
+
+		CGFloat compo[4];
+		compo[0] = (CGFloat)(frameBuf[0] / 255.0f);
+		compo[1] = (CGFloat)(frameBuf[1] / 255.0f);
+		compo[2] = (CGFloat)(frameBuf[2] / 255.0f);
+		compo[3] = (CGFloat)255.0f;
+		
+		CGImageRef tmpCGImg2 = CGImageCreateWithMaskingColors(tmpCGImg, compo);
+		[buf release];
+		buf = [UIImage imageWithCGImage:tmpCGImg2];
+
+		break;
+	} while( 0 );
+
+	pImage = new WSDimage( buf );
+#else
+	WSCstring ext = FileList::getExt( path );
+	do {
+		if( (ext != "bmp") && (ext != "BMP") )
+			break;
+		
+		CGColorSpaceRef colorSpace = CGColorSpaceCreateDeviceRGB();
+		
+		long w = CGImageGetWidth(tmpCGImg);
+		long h = CGImageGetHeight(tmpCGImg);
+		unsigned char *frameBuf = (unsigned char*)malloc(w * h * 4);
+		
+		CGContextRef tmpContext = CGBitmapContextCreate(frameBuf, w, h, 8, w * 4, colorSpace, kCGImageAlphaPremultipliedLast);
+		CGContextDrawImage(tmpContext, CGRectMake(0, 0, w, h), tmpCGImg);
+		CGContextRelease(tmpContext);
+		
+		CGColorSpaceRelease(colorSpace);
+		
+		CGFloat compo[4];
+		compo[0] = (CGFloat)(frameBuf[0] / 255.0f);
+		compo[1] = (CGFloat)(frameBuf[1] / 255.0f);
+		compo[2] = (CGFloat)(frameBuf[2] / 255.0f);
+		compo[3] = (CGFloat)255.0f;
+		
+		CGImageRef tmpCGImg2 = CGImageCreateWithMaskingColors(tmpCGImg, compo);
+		[buf release];
+		buf = [[NSImage alloc] initWithCGImage:tmpCGImg2 size:NSZeroSize];
+		
+		break;
+	} while( 0 );
+	
+	pImage = new WSDimage( buf );
+#endif //@@@
+#endif // D_MAC
+
 #ifdef D_IPHONE
 	NSString *pathStr = [NSString stringWithUTF8String:(const char *)path];
 	UIImage *tmpUIImg = [[UIImage alloc] initWithContentsOfFile:pathStr];
@@ -245,6 +338,11 @@ void Pcg::load( WSCstring path )
 	nHeight = pImage->getImageHeight();
 #endif // D_GTK
 
+#ifdef D_MAC
+	nWidth = pImage->getImageWidth();
+	nHeight = pImage->getImageHeight();
+#endif // D_MAC
+
 #ifdef D_IPHONE
 	nWidth = pImage->getImageWidth();
 	nHeight = pImage->getImageHeight();
@@ -422,6 +520,43 @@ bool Pcg::draw( WSDmwindowDev *mDev,
 			0, 0 );
 #endif // D_GTK
 
+#ifdef D_MAC
+#if 0
+//@@@
+	y = MAP_MAX_Y * 32 - y - h;
+	long srcY = pImage->getImageHeight() - h;
+	
+	NSImage *pcgCGImage = pImage->getPixbuf();
+	NSImage *context = mDev->getPixMap();
+	
+	[context lockFocus];
+	[pcgCGImage dissolveToPoint:NSMakePoint( x, y ) fromRect:NSMakeRect( 0.0, srcY, w, h ) fraction:1.0];
+	[context unlockFocus];
+#else
+	NSImage *pcgUIImage = pImage->getPixbuf();
+	CGImageRef pcgCGImage = [pcgUIImage CGImageForProposedRect:nil context:nil hints:nil];
+	CGContextRef context = mDev->getPixMap();
+
+	CGRect pcgRect;
+	pcgRect.size.width = [pcgUIImage size].width;
+	pcgRect.size.height = [pcgUIImage size].height;
+
+	CGRect clipRect;
+	clipRect.origin.x = x;
+	clipRect.origin.y = -y - h;
+	clipRect.size.width = w;
+	clipRect.size.height = h;
+
+	pcgRect.origin.x = x;
+	pcgRect.origin.y = -y - h;
+
+	CGContextSaveGState(context);
+	CGContextClipToRect(context, clipRect);
+	CGContextDrawImage(context, pcgRect, pcgCGImage);
+	CGContextRestoreGState(context);
+#endif //@@@
+#endif // D_MAC
+
 #ifdef D_IPHONE
 	UIImage *pcgUIImage = pImage->getPixbuf();
 	CGImageRef pcgCGImage = pcgUIImage.CGImage;
@@ -533,6 +668,43 @@ bool Pcg::drawFix( WSDmwindowDev *mDev,
 					0, 0 );
 #endif // D_GTK
 
+#ifdef D_MAC
+#if 0
+//@@@
+			long yyy = MAP_MAX_Y * 32 - yy - drawH;
+			long srcY = pImage->getImageHeight() - drawH;
+			
+			NSImage *pcgCGImage = pImage->getPixbuf();
+			NSImage *context = mDev->getPixMap();
+			
+			[context lockFocus];
+			[pcgCGImage dissolveToPoint:NSMakePoint( xx, yyy ) fromRect:NSMakeRect( 0.0, srcY, drawW, drawH ) fraction:1.0];
+			[context unlockFocus];
+#else
+			NSImage *pcgUIImage = pImage->getPixbuf();
+			CGImageRef pcgCGImage = [pcgUIImage CGImageForProposedRect:nil context:nil hints:nil];
+			CGContextRef context = mDev->getPixMap();
+			
+			CGRect pcgRect;
+			pcgRect.size.width = pcgUIImage.size.width;
+			pcgRect.size.height = pcgUIImage.size.height;
+			
+			CGRect clipRect;
+			clipRect.origin.x = xx;
+			clipRect.origin.y = -yy - ih;
+			clipRect.size.width = drawW;
+			clipRect.size.height = drawH;
+			
+			pcgRect.origin.x = xx;
+			pcgRect.origin.y = -yy - ih;
+			
+			CGContextSaveGState(context);
+			CGContextClipToRect(context, clipRect);
+			CGContextDrawImage(context, pcgRect, pcgCGImage);
+			CGContextRestoreGState(context);
+#endif //@@@
+#endif // D_MAC
+
 #ifdef D_IPHONE
 			UIImage *pcgUIImage = pImage->getPixbuf();
 			CGImageRef pcgCGImage = pcgUIImage.CGImage;
@@ -640,6 +812,43 @@ bool Pcg::drawIdx( WSDmwindowDev *mDev,
 			0, 0 );
 #endif // D_GTK
 
+#ifdef D_MAC
+#if 0
+//@@@
+	y = MAP_MAX_Y * 32 - y - sizeY;
+	long iy = pImage->getImageHeight() - (idxY * sizeY) - sizeY;
+	
+	NSImage *pcgCGImage = pImage->getPixbuf();
+	NSImage *context = mDev->getPixMap();
+	
+	[context lockFocus];
+	[pcgCGImage dissolveToPoint:NSMakePoint( x, y ) fromRect:NSMakeRect( idxX * sizeX, iy, sizeX, sizeY ) fraction:1.0];
+	[context unlockFocus];
+#else
+	NSImage *pcgUIImage = pImage->getPixbuf();
+	CGImageRef pcgCGImage = [pcgUIImage CGImageForProposedRect:nil context:nil hints:nil];
+	CGContextRef context = mDev->getPixMap();
+	
+	CGRect pcgRect;
+	pcgRect.size.width = pcgUIImage.size.width;
+	pcgRect.size.height = pcgUIImage.size.height;
+	
+	CGRect clipRect;
+	clipRect.origin.x = x;
+	clipRect.origin.y = -y - sizeY;
+	clipRect.size.width = sizeX;
+	clipRect.size.height = sizeY;
+	
+	pcgRect.origin.x = x - (idxX * sizeX);
+	pcgRect.origin.y = -y - pcgRect.size.height + (idxY * sizeY);
+	
+	CGContextSaveGState(context);
+	CGContextClipToRect(context, clipRect);
+	CGContextDrawImage(context, pcgRect, pcgCGImage);
+	CGContextRestoreGState(context);
+#endif //@@@
+#endif // D_MAC
+
 #ifdef D_IPHONE
 	UIImage *pcgUIImage = pImage->getPixbuf();
 	CGImageRef pcgCGImage = pcgUIImage.CGImage;
@@ -662,7 +871,7 @@ bool Pcg::drawIdx( WSDmwindowDev *mDev,
 	CGContextDrawImage(context, pcgRect, pcgCGImage);
 	CGContextRestoreGState(context);
 #endif // D_IPHONE
-
+	
 #ifdef D_MFC
 	g_Dir3d.Draw(
 			pImage,
@@ -743,6 +952,52 @@ bool Pcg::drawOffset( WSDmwindowDev *mDev,
 			0, 0 );
 #endif // D_GTK
 
+#ifdef D_MAC
+	if( x < 0 )
+		x = 0;
+	if( y < 0 )
+		y = 0;
+	if( w > pImage->getImageWidth() )
+		w = pImage->getImageWidth();
+	if( h > pImage->getImageHeight() )
+		h = pImage->getImageHeight();
+
+#if 0
+//@@@
+	y = MAP_MAX_Y * 32 - y - h;
+	offsetY = pImage->getImageHeight() - offsetY - h;
+	
+	NSImage *pcgCGImage = pImage->getPixbuf();
+	NSImage *context = mDev->getPixMap();
+
+	[context lockFocus];
+	[pcgCGImage dissolveToPoint:NSMakePoint( x, y ) fromRect:NSMakeRect( offsetX, offsetY, w, h ) fraction:1.0];
+	[context unlockFocus];
+#else
+	NSImage *pcgUIImage = pImage->getPixbuf();
+	CGImageRef pcgCGImage = [pcgUIImage CGImageForProposedRect:nil context:nil hints:nil];
+	CGContextRef context = mDev->getPixMap();
+	
+	CGRect pcgRect;
+	pcgRect.size.width = pcgUIImage.size.width;
+	pcgRect.size.height = pcgUIImage.size.height;
+	
+	CGRect clipRect;
+	clipRect.origin.x = x;
+	clipRect.origin.y = -y - h;
+	clipRect.size.width = w;
+	clipRect.size.height = h;
+	
+	pcgRect.origin.x = x - offsetX;
+	pcgRect.origin.y = -y - pcgRect.size.height + offsetY;
+	
+	CGContextSaveGState(context);
+	CGContextClipToRect(context, clipRect);
+	CGContextDrawImage(context, pcgRect, pcgCGImage);
+	CGContextRestoreGState(context);
+#endif //@@@
+#endif // D_MAC
+
 #ifdef D_IPHONE
 	if( x < 0 )
 		x = 0;
