@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2011 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2014 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: Pcg.h,v 1.22 2011/01/09 01:59:31 bowkenken Exp $
+* $Id: Pcg.h,v 1.24 2014/01/07 23:44:46 bowkenken Exp $
 ***************************************************************/
 
 #ifndef PCG_H
@@ -47,6 +47,12 @@
 # include "GtkWSCstring.h"
 #endif // D_GTK
 
+#ifdef D_MAC
+# include "MacWSDimage.h"
+# include "MacWSDmwindowDev.h"
+# include "MacWSCstring.h"
+#endif // D_MAC
+
 #ifdef D_IPHONE
 # include "IPhoneWSDimage.h"
 # include "IPhoneWSDmwindowDev.h"
