@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2011 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2014 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: PcgDun.h,v 1.85 2011/01/09 01:59:31 bowkenken Exp $
+* $Id: PcgDun.h,v 1.88 2014/01/07 23:44:46 bowkenken Exp $
 ***************************************************************/
 
 #ifndef PCG_DUN_H
@@ -58,6 +58,10 @@
 # include "GtkWSCstring.h"
 #endif //D_GTK
 
+#ifdef D_MAC
+# include "MacWSCstring.h"
+#endif //D_MAC
+
 #ifdef D_IPHONE
 # include "IPhoneWSCstring.h"
 #endif //D_IPHONE
@@ -260,6 +264,11 @@ private:
 	gint nSignboardWidth, nSignboardAscent, nSignboardDescent;
 #endif // D_GTK
 
+#ifdef D_MAC
+	// եȤΥ
+	void *pSignboardStyle;
+#endif // D_MAC
+
 #ifdef D_IPHONE
 	// եȤΥ
 	void *pSignboardStyle;
@@ -297,6 +306,12 @@ private:
 	gint nWidthVfx, nAscentVfx, nDescentVfx;
 #endif // D_GTK
 
+#ifdef D_MAC
+	// եȤΥ
+	void *pStyle;
+	void *pStyleVfx;
+#endif // D_MAC
+
 #ifdef D_IPHONE
 	// եȤΥ
 	void *pStyle;
@@ -379,6 +394,7 @@ public:
 	void setXxAttack( xx_act_kind_t kind, void *p );
 
 	void setFlgUpdateRequest( bool flg );
+	bool getFlgUpdateRequest();
 	void setFlgUpdateRequestIPhone( bool flg );
 	bool getFlgUpdateRequestIPhone();
 
@@ -503,9 +519,7 @@ private:
 #endif // D_GTK
 /*
 	void setFlgUpdateRequest( bool flg );
-*/
 	bool getFlgUpdateRequest();
-/*
 	void setFlgUpdateRequestIPhone( bool flg );
 	bool getFlgUpdateRequestIPhone();
 */
