@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2011 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2014 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: SelConf.h,v 1.15 2011/01/09 01:59:31 bowkenken Exp $
+* $Id: SelConf.h,v 1.17 2014/01/07 23:44:46 bowkenken Exp $
 ***************************************************************/
 
 #ifndef SEL_CONF_H
@@ -42,7 +42,10 @@
 #include <stdlib.h>
 #include <stdio.h>
 
-#if defined( D_WS ) || defined( D_GTK ) || defined( D_IPHONE )
+#if defined( D_WS ) \
+	|| defined( D_GTK ) \
+	|| defined( D_MAC ) \
+	|| defined( D_IPHONE )
 # include <dirent.h>
 # include <sys/stat.h>
 #endif
