@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2014 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: call.cpp,v 1.127 2010/08/01 16:55:10 bowkenken Exp $
+* $Id: call.cpp,v 1.132 2014/03/15 00:50:40 bowkenken Exp $
 ***************************************************************/
 
 #define	CALL_CPP
@@ -197,6 +197,30 @@ const char	*call_get_home_dir( void )
 	return [[NSString stringWithFormat:@"%@/Documents", NSHomeDirectory()] cString];
 #endif // D_IPHONE
 
+#if defined( D_DOS ) || defined( D_MFC )
+	char strPath[_MAX_PATH + 1];
+	char strDrive[_MAX_DRIVE + 1];
+	char strDir[_MAX_DIR + 1];
+	char strFName[_MAX_FNAME + 1];
+	char strExt[_MAX_EXT + 1];
+
+	int nLen = ::GetModuleFileName( NULL, (LPTSTR)strPath, _MAX_PATH );
+	if( nLen <= 0 )
+		return NULL;
+
+	::_splitpath(
+			strPath,
+			strDrive,
+			strDir,
+			strFName,
+			strExt);
+
+	static char strRes[_MAX_PATH + 1];
+	sn_printf( strRes, _MAX_PATH, "%s%s", strDrive, strDir );
+
+	return strRes;
+#endif // D_DOS || D_MFC
+
 	return NULL;
 }
 
@@ -1964,3 +1988,14 @@ void	call_sleep( long n )
 	::Sleep( n );
 #endif	/* D_MFC */
 }
+
+/***************************************************************
+* ꡼å
+***************************************************************/
+
+void	check_memory_gui( void )
+{
+#ifdef	D_ALL_GUI
+	check_memory_GlobalVar_cpp();
+#endif
+}
