@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2014 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: ending-space.c,v 1.12 2009/09/12 22:50:47 bowkenken Exp $
+* $Id: ending-space.c,v 1.19 2014/01/08 01:01:27 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -91,22 +91,24 @@ check_memory_def( check_memory_ending_space_c_FLICKER_N )
 const char	*g_str_staff_roll[] = {
 	"            Director  bowkenken",
 	" ",
-	" ",
 	"         Programming  bowkenken",
 	" ",
 	"                  Graphic",
 	"                  Design",
-	"           Character  [RPG DOT]",
-	"                Item  Whitecat",
+	"          Characters  [RPG DOT]",
+	"               Items  Whitecat",
 	"                 Map  REFMAP",
 	"              Anchor  kokusi(yujyu)",
 	"           Sanctuary  hiyo",
+	"      Visual Effects  moja",
 	"            Openning  URARA",
 	"           Last Boss  naramura",
+	"       Denzi's Tiles  Denzi",
 	" ",
 	"   Ending Photograph  Yoshinori Kamimura",
 	" ",
 	"    Music Production  Presence of Music",
+	"       Sound Effects  OSA at The Match Makers",
 	" ",
 	"       Super Adviser  nnn",
 	"                      lu",
@@ -114,9 +116,8 @@ const char	*g_str_staff_roll[] = {
 	"      Special Thanks  t-oikawa",
 	"                      TeaMiKL",
 	" ",
-	" ",
 	"        L&L - Labyrinths & Legends        ",
-	"          Copyright (c) 1993-2009         ",
+	"          Copyright (c) 1993-2014         ",
 	"            YOSHIMURA, Tomohiko           ",
 	"           All rights reserved.           ",
 	" ",
@@ -124,7 +125,6 @@ const char	*g_str_staff_roll[] = {
 	"E-mail: bowkenken@users.sourceforge.jp",
 	" ",
 	" ",
-	" ",
 	"        Presented by  bowkenken",
 	" ",
 	" ",
@@ -278,7 +278,7 @@ bool_t	draw_space( bool_t flg_draw_staff_roll )
 		draw_staff_roll();
 
 	set_crsr( 0, 0 );
-	wait_100_msec();
+	sleep_msec( 100 );
 
 	return TRUE;
 }
