@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2014 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: fight.c,v 1.173 2010/08/17 13:57:05 bowkenken Exp $
+* $Id: fight.c,v 1.180 2014/03/13 18:30:01 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -1158,8 +1158,8 @@ bool_t	fight_x_1(
 	long	d_def, d_ac;
 	rate_t	d_resi;
 	abl_val_t	*d_hp;
-	fx_t	*d_fx;
 	long	d_x, d_y;
+	rate_t	o_cont, d_cont;
 	flg_stat_t	stat;
 	item_t	*eq;
 	pos_t	bgn, end;
@@ -1289,13 +1289,11 @@ bool_t	fight_x_1(
 	if( flg_d_null ){
 		str_nz_cpy( d_name, MSG_NULL, CHR_NAME_MAX_BYTE );
 		d_hp = NULL;
-		d_fx = NULL;
 		d_x = o_p->trgt.true_x;
 		d_y = o_p->trgt.true_y;
 	} else {
 		str_nz_cpy( d_name, d_p->name, CHR_NAME_MAX_BYTE );
 		d_hp = &(d_p->abl.hp);
-		d_fx = &(d_p->fx);
 		d_x = d_p->x;
 		d_y = d_p->y;
 	}
@@ -1420,6 +1418,8 @@ bool_t	fight_x_1(
 
 	/* ɸ¦Υǡ */
 
+	d_cont = use_contribution_rate( d_p );
+
 	if( flg_d_null ){
 		d_def = 0;
 		d_ac = 0;
@@ -1427,7 +1427,10 @@ bool_t	fight_x_1(
 	} else {
 		d_def = get_def( d_p );
 		d_def = roll_dice( d_def, FALSE );
+		/* ʡ */
 		d_def += d_def * d_p->fx_data.bless;
+		/*  */
+		d_def = d_def * d_cont / _100_PERCENT;
 		d_ac = get_ac( d_p );
 		if( d_k == CHR_KIND_MBR ){
 			if( ((mbr_t *)d_p)->act.kind == ACT_KIND_NULL ){
@@ -1445,9 +1448,14 @@ bool_t	fight_x_1(
 
 	/* ¦Υǡ */
 
+	o_cont = use_contribution_rate( o_p );
+
 	o_hit = get_hit( o_p, attack );
 	o_hit = roll_dice( o_hit, FALSE );
+	/* ʡ */
 	o_hit += o_hit * o_p->fx_data.bless;
+	/*  */
+	o_hit = o_hit * o_cont / _100_PERCENT;
 	o_hit = o_hit * get_chr_throw_range_rate( o_p, d_p ) / _100_PERCENT;
 
 	o_dam = get_dam( o_p, attack );
@@ -1555,27 +1563,33 @@ bool_t	fight_x_1(
 					o_name, d_name );
 		}
 
-		if( o_k != CHR_KIND_MBR )
-			return FALSE;
-		if( eq == NULL )
-			return FALSE;
-		if( !attack->flg_throw )
-			return FALSE;
+		do {
+			if( o_k != CHR_KIND_MBR )
+				break;
+			if( eq == NULL )
+				break;
+			if( !attack->flg_throw )
+				break;
 
-		/* ֹν */
+			/* ֹν */
 
-		if( chk_come_back_arw( (mbr_t *)o_p ) ){
-			/* ֡Τ褦äƤ */
-			vfx_arw( o_k, &end, &bgn, gui_vfx,
-					mjr, ANIM_ARW_LEN );
-		} else {
-			/*  */
-			dec_throw( (mbr_t *)o_p, TRUE, d_x, d_y );
-		}
+			if( chk_come_back_arw( (mbr_t *)o_p ) ){
+				/* ֡Τ褦äƤ */
+				vfx_arw( o_k, &end, &bgn, gui_vfx,
+						mjr, ANIM_ARW_LEN );
+			} else {
+				/*  */
+				dec_throw( (mbr_t *)o_p, TRUE, d_x, d_y );
+			}
+		} while( 0 );
+
+		free_gui_vfx( gui_vfx );
 
 		return FALSE;
 	}
 
+	free_gui_vfx( gui_vfx );
+
 	/* 񤹤 */
 
 	do {
@@ -1980,6 +1994,7 @@ bool_t	spell_attack(
 		gui_vfx = alloc_gui_vfx_spell( resi );
 		vfx_arw( o_p->kind, &o_pos, &d_pos, gui_vfx,
 				mjr, ANIM_ARW_LEN );
+		free_gui_vfx( gui_vfx );
 	}
 
 	/* ޡ饹 */
@@ -2211,8 +2226,6 @@ void	added_fx_wpn_randm_art_item(
 
 void	fight_fx( chr_t *o_p, chr_t *d_p, const attack_t *attack )
 {
-	long	o_lev;
-
 	if( o_p == NULL )
 		return;
 	if( d_p == NULL )
@@ -2222,8 +2235,6 @@ void	fight_fx( chr_t *o_p, chr_t *d_p, const attack_t *attack )
 	if( attack->fx_kind == FX_KIND_NULL )
 		return;
 
-	o_lev = get_specialist_lev( o_p );
-
 	if( !resi_roll( o_p, ABL_KIND_MAX_N, d_p, attack->resi_kind ) )
 		set_fx( d_p, attack->fx_kind, attack->fx_turn );
 }
@@ -2238,10 +2249,8 @@ void	fight_fx( chr_t *o_p, chr_t *d_p, const attack_t *attack )
 bool_t	chr_break_door( chr_t *chr, long dr_n )
 {
 	long	hit;
-	dun_t	*dun;
 	attack_t	attack;
-
-	dun = get_dun();
+	rate_t	cont;
 
 	if( chr == NULL )
 		return FALSE;
@@ -2251,8 +2260,14 @@ bool_t	chr_break_door( chr_t *chr, long dr_n )
 	else
 		hit = get_hit( chr, NULL );
 	hit = roll_dice( hit, FALSE );
+
+	/* ʡ */
 	hit += hit * chr->fx_data.bless;
 
+	/*  */
+	cont = use_contribution_rate( chr );
+	hit = hit * cont / _100_PERCENT;
+
 	if( DOOR_DEF > hit ){
 		print_msg_mbr( chr, FLG_MSG_ERR, MSG_ERR_DOOR_BREAK_LEV,
 				chr->name );
@@ -2280,6 +2295,7 @@ bool_t	chr_break_trap( chr_t *chr, trap_t *trap )
 {
 	long	hit;
 	attack_t	attack;
+	rate_t	cont;
 
 	if( chr == NULL )
 		return FALSE;
@@ -2289,8 +2305,14 @@ bool_t	chr_break_trap( chr_t *chr, trap_t *trap )
 	else
 		hit = get_hit( chr, NULL );
 	hit = roll_dice( hit, FALSE );
+
+	/* ʡ */
 	hit += hit * chr->fx_data.bless;
 
+	/*  */
+	cont = use_contribution_rate( chr );
+	hit = hit * cont / _100_PERCENT;
+
 	if( TRAP_DEF > hit ){
 		print_msg( FLG_MSG_ERR, MSG_ERR_TRAP_BREAK_LEV );
 
@@ -2315,6 +2337,7 @@ bool_t	chr_break_item( chr_t *chr, item_t *item )
 {
 	long	hit;
 	attack_t	attack;
+	rate_t	cont;
 	char	name[ITEM_NAME_MAX_BYTE + 1];
 
 	if( chr == NULL )
@@ -2334,8 +2357,14 @@ bool_t	chr_break_item( chr_t *chr, item_t *item )
 	else
 		hit = get_hit( chr, NULL );
 	hit = roll_dice( hit, FALSE );
+
+	/* ʡ */
 	hit += hit * chr->fx_data.bless;
 
+	/*  */
+	cont = use_contribution_rate( chr );
+	hit = hit * cont / _100_PERCENT;
+
 	if( ITEM_DEF > hit ){
 		print_msg( FLG_MSG_ERR, MSG_ERR_ITEM_BREAK_LEV,
 				item->name );
@@ -2831,7 +2860,15 @@ abl_kind_t	get_def_abl( chr_t *p )
 		else
 			return ABL_KIND_FIG;
 	} else {
-		return ABL_KIND_FIG;
+		long	lev_fig, lev_mon;
+
+		lev_fig = get_lev( p, ABL_KIND_FIG );
+		lev_mon = get_lev( p, ABL_KIND_MON );
+
+		if( lev_fig > lev_mon )
+			return ABL_KIND_FIG;
+		else
+			return ABL_KIND_MON;
 	}
 
 	return ABL_KIND_FIG;
