@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2014 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gf-gconf.c,v 1.4 2010/01/07 07:12:21 bowkenken Exp $
+* $Id: gf-gconf.c,v 1.8 2014/01/07 23:40:42 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -66,7 +66,7 @@ bool_t	load_graph_conf( char *path )
 
 	/* СΥå */
 
-	if( !chk_ver_old( &ver,
+	if( chk_ver_new( &ver,
 			GRAPH_CONF_VER_MJR,
 			GRAPH_CONF_VER_MNR,
 			GRAPH_CONF_VER_PAT ) ){
@@ -317,7 +317,7 @@ bool_t	load_graph_conf_set_val(
 	char *id, long val
 )
 {
-#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+#ifdef	D_ALL_GUI
 	if( strcmp( id, "scale" ) == 0 ){
 		return call_sel_conf_eval_set_num(
 				GRAPH_CONF_TOKEN_SCALE, val );
@@ -369,7 +369,7 @@ bool_t	load_graph_conf_set_str(
 	char *id, char *str
 )
 {
-#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+#ifdef	D_ALL_GUI
 	if( strcmp( id, "title" ) == 0 ){
 		return call_sel_conf_eval_set_str(
 				GRAPH_CONF_TOKEN_TITLE, str );
