@@ -144,7 +144,7 @@ request_kind_t	trans_idx_to_request_kind( long idx );
 long	trans_request_kind_to_idx( request_kind_t k );
 long	get_stay_inn_kind_trans_tab_max_n( void );
 stay_inn_kind_t	trans_idx_to_stay_inn_kind( long idx );
-long	trans_stay_inn_kind_to_idx( request_kind_t k );
+long	trans_stay_inn_kind_to_idx( stay_inn_kind_t k );
 bool_t	copy_file( const char *src, const char *dst );
 char	*cat_path( const char *path, const char *file );
 bool_t	chk_exist_file( const char *s );
