@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2014 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: last-boss.c,v 1.90 2010/09/01 09:32:14 bowkenken Exp $
+* $Id: last-boss.c,v 1.96 2014/01/08 01:01:27 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -134,9 +134,11 @@ check_memory_def( check_memory_last_boss_c_flg_open_xx_jaw )
 * XX βǮ
 ***************************************************************/
 
+static const long	XX_HEAT_ANIME_N = 1;
+
 /* δֳ */
 static const long	XX_HEAT_DY = 3;
-static const long	XX_HEAT_ANIME_N = 5;
+static const long	XX_HEAT_BLAST_ANIME_N = 5;
 check_memory_def( check_memory_last_boss_c_XX_HEAT_DY )
 
 static const long	XX_HEAT_WAIT_FRAME_N = 3;
@@ -195,9 +197,9 @@ static const rate_t	XX_COLD_LASER_ADD_LEN = 1;
 check_memory_def( check_memory_last_boss_c_XX_COLD_LASER_MAX_LEN )
 
 static const long	XX_COLD_BIT_WAIT_FRAME_N = 3;
-static const long	XX_COLD_NEXT_WAIT_FRAME_N = 30;
+static const long	XX_COLD_NEXT_WAIT_FRAME_N = 10;
 static const long	XX_COLD_LASER_WAIT_FRAME_N = 3;
-static const long	XX_COLD_END_WAIT_FRAME_N = 60;
+static const long	XX_COLD_END_WAIT_FRAME_N = 20;
 check_memory_def( check_memory_last_boss_c_XX_COLD_BIT_WAIT_FRAME_N )
 
 static const char	*xx_laser[MBR_MAX_N] = {
@@ -291,7 +293,7 @@ check_memory_def( check_memory_last_boss_c_xx_bit )
 static const rate_t	XX_MIND_ADD_RATE = 10;
 check_memory_def( check_memory_last_boss_c_XX_MIND_ADD_RATE )
 
-static const long	XX_MIND_ANIME_N = 5;
+static const long	XX_MIND_ANIME_N = 3;
 static const long	XX_MIND_WAIT_FRAME_N = 3;
 check_memory_def( check_memory_last_boss_c_XX_MIND_ANIME_N )
 
@@ -307,7 +309,7 @@ static void xx_mind_draw( xx_mind_t *xx_mind );
 * XX ڻ
 ***************************************************************/
 
-#define	XX_ACID_HOMING_V	(1 * XX_ACID_HOMING_FIX_POINT)
+static const long	XX_ACID_ANIME_N = 1;
 
 static const long	XX_ACID_MAX_Q = 18;
 check_memory_def( check_memory_last_boss_c_XX_ACID_MAX_Q )
@@ -315,6 +317,7 @@ check_memory_def( check_memory_last_boss_c_XX_ACID_MAX_Q )
 static const long	XX_ACID_WAIT_FRAME_N = 3;
 check_memory_def( check_memory_last_boss_c_XX_ACID_WAIT_FRAME_N )
 
+#define	XX_ACID_HOMING_V	(1 * XX_ACID_HOMING_FIX_POINT)
 static pos_t	xx_homing_bgn_v[MBR_MAX_N] = {
 	{ 0, -XX_ACID_HOMING_V },
 	{ 0, -XX_ACID_HOMING_V },
@@ -338,7 +341,7 @@ static void xx_acid_draw( xx_acid_t *xx_acid );
 * XX βžƹ
 ***************************************************************/
 
-static const long	XX_ROTATION_ANIME_N = 2;
+static const long	XX_ROTATION_ANIME_N = 1;
 static const long	XX_ROTATION_WAIT_FRAME_N = 6;
 check_memory_def( check_memory_last_boss_c_XX_ROTATION_ANIME_N )
 
@@ -349,7 +352,7 @@ check_memory_def( check_memory_last_boss_c_xx_rotation_str )
 * XX αƹ
 ***************************************************************/
 
-static const long	XX_WHIRL_ANIME_N = 2;
+static const long	XX_WHIRL_ANIME_N = 1;
 static const long	XX_WHIRL_WAIT_FRAME_N = 3;
 check_memory_def( check_memory_last_boss_c_XX_WHIRL_ANIME_N )
 
@@ -360,7 +363,7 @@ check_memory_def( check_memory_last_boss_c_xx_whirl_str )
 * XX ƹ
 ***************************************************************/
 
-static const long	XX_FAN_ANIME_N = 2;
+static const long	XX_FAN_ANIME_N = 1;
 static const long	XX_FAN_WAIT_FRAME_N = 3;
 check_memory_def( check_memory_last_boss_c_XX_FAN_ANIME_N )
 
@@ -371,6 +374,7 @@ check_memory_def( check_memory_last_boss_c_xx_fan_str )
 * XX ʿǤ
 ***************************************************************/
 
+static const long	XX_SLAP_ANIME_N = 1;
 static const long	XX_SLAP_WAIT_FRAME_N = 60;
 check_memory_def( check_memory_last_boss_c_XX_SLAP_WAIT_FRAME_N )
 
@@ -801,6 +805,9 @@ void	draw_last_boss( void )
 		break;
 	case LAST_SCENE_N_ENCOUNTER:
 		scroll_last_boss();
+		draw_exel();
+		draw_exeler();
+		draw_xex();
 		wait_frame_gui( REDRAW_ALL_WAIT_FRAME_N );
 		break;
 	case LAST_SCENE_N_ENCOUNTER_CUT_IN:
@@ -1041,6 +1048,19 @@ void	draw_words_xx( const char *str )
 	draw_words( MSG_MNSTR_XX, str );
 }
 
+/***************************************************************
+* 
+***************************************************************/
+
+void	draw_exel( void )
+{
+	mnstr_t	*p;
+
+	p = get_last_boss( LAST_BOSS_KIND_EXEL );
+	set_map_chr( p );
+	draw_mnstr( p );
+}
+
 /***************************************************************
 * оǥ
 ***************************************************************/
@@ -1145,6 +1165,19 @@ void	draw_exel_hyper( void )
 	}
 }
 
+/***************************************************************
+* 顼
+***************************************************************/
+
+void	draw_exeler( void )
+{
+	mnstr_t	*p;
+
+	p = get_last_boss( LAST_BOSS_KIND_EXELER );
+	set_map_chr( p );
+	draw_mnstr( p );
+}
+
 /***************************************************************
 * 顼оǥ
 ***************************************************************/
@@ -1265,6 +1298,19 @@ void	draw_exeler_hyper( void )
 	}
 }
 
+/***************************************************************
+* 
+***************************************************************/
+
+void	draw_xex( void )
+{
+	mnstr_t	*p;
+
+	p = get_last_boss( LAST_BOSS_KIND_XEX );
+	set_map_chr( p );
+	draw_mnstr( p );
+}
+
 /***************************************************************
 * ȥ顼оǥκɸ
 ***************************************************************/
@@ -2448,7 +2494,6 @@ void	set_map_total_last_boss(
 )
 {
 	dun_t	*dun;
-	char	transmit_chr;
 	long	bx, by;
 	long	ex, ey;
 	long	xx, yy;
@@ -2462,7 +2507,6 @@ void	set_map_total_last_boss(
 		return;
 
 	dun = get_dun();
-	transmit_chr = ptn->transmit_chr;
 
 	bx = x;
 	by = y;
@@ -2535,7 +2579,7 @@ pos_t	get_xx_pos( void )
 void	wait_frame_gui( long frame )
 {
 	if( g_flg_gui )
-		wait_100_n_msec( 5 );
+		wait_frame( frame );
 }
 
 /***************************************************************
@@ -2704,12 +2748,14 @@ void	xx_spell( mnstr_t *p, spell_kind_t kind )
 
 void	xx_act_heat( mnstr_t *p )
 {
+	long	i;
+
 	set_open_xx_jaw( TRUE );
 
-	play_sound_xx( XX_ACT_KIND_HEAT );
-	xx_act_heat_draw( p );
-	play_sound_xx( XX_ACT_KIND_HEAT );
-	xx_act_heat_draw( p );
+	for( i = 0; i < XX_HEAT_ANIME_N; i++ ){
+		play_sound_xx( XX_ACT_KIND_HEAT );
+		xx_act_heat_draw( p );
+	}
 
 	redraw_map();
 
@@ -2743,7 +2789,7 @@ void	xx_act_heat_draw( mnstr_t *p )
 		xx_heat.blast_m[n] = 0;
 	}
 
-	end_y = bgn.y + AREA_MAX_Y + (blast_max_n * XX_HEAT_ANIME_N);
+	end_y = bgn.y + AREA_MAX_Y + (blast_max_n * XX_HEAT_BLAST_ANIME_N);
 
 	for( i = 0; i < LOOP_MAX_100; i++ ){
 		if( xx_heat.head_y > end_y )
@@ -2765,7 +2811,7 @@ void	xx_act_heat_draw( mnstr_t *p )
 				continue;
 
 			xx_heat.blast_m[n] = xx_heat.blast_n[n]
-					/ XX_HEAT_ANIME_N;
+					/ XX_HEAT_BLAST_ANIME_N;
 			m = xx_heat.blast_m[n];
 			if( m >= blast_max_n )
 				continue;
@@ -3179,12 +3225,14 @@ static void xx_mind_draw( xx_mind_t *xx_mind )
 
 void	xx_act_acid( mnstr_t *p )
 {
+	long	i;
+
 	set_open_xx_jaw( TRUE );
 
-	play_sound_xx( XX_ACT_KIND_ACID );
-	xx_act_acid_draw( p );
-	play_sound_xx( XX_ACT_KIND_ACID );
-	xx_act_acid_draw( p );
+	for( i = 0; i < XX_ACID_ANIME_N; i++ ){
+		play_sound_xx( XX_ACT_KIND_ACID );
+		xx_act_acid_draw( p );
+	}
 
 	redraw_map();
 
@@ -3946,10 +3994,12 @@ void	xx_act_fan_draw( mnstr_t *p )
 
 void	xx_act_slap( mnstr_t *p )
 {
-	play_sound_xx( XX_ACT_KIND_SLAP );
-	xx_act_slap_draw( p );
-	play_sound_xx( XX_ACT_KIND_SLAP );
-	xx_act_slap_draw( p );
+	long	i;
+
+	for( i = 0; i < XX_SLAP_ANIME_N; i++ ){
+		play_sound_xx( XX_ACT_KIND_SLAP );
+		xx_act_slap_draw( p );
+	}
 
 	redraw_map();
 }
