@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2014 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: main-dos.c,v 1.18 2009/01/04 00:24:52 bowkenken Exp $
+* $Id: main-dos.c,v 1.22 2014/01/07 23:40:42 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -70,3 +70,11 @@ void	gexit( long code )
 {
 	exit( code );
 }
+
+/***************************************************************
+* ꡼å
+***************************************************************/
+
+void	check_memory_main_dos_c( void )
+{
+}
