@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2014 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: menu.c,v 1.233 2010/05/13 17:31:58 bowkenken Exp $
+* $Id: menu.c,v 1.236 2014/01/07 23:40:42 bowkenken Exp $
 ***************************************************************/
 
 #define	MENU_C
@@ -1597,7 +1597,6 @@ char	*cb_menu_ask_no( menu_t **pp, menu_t **dflt )
 char	*exec_menu_sel_num( long *p, long min, long max )
 {
 	long	n;
-	volatile long	gui_n;
 	long	figure;
 	long	sel_n;
 	char	num[FIGURE_MAX_N];
@@ -1608,7 +1607,6 @@ char	*exec_menu_sel_num( long *p, long min, long max )
 		return STR_MENU_ERR;
 
 	n = *p;
-	gui_n = n;
 
 	figure = 0;
 	if( labs( min ) < labs( max ) )
@@ -1719,7 +1717,6 @@ char	*exec_menu_sel_num( long *p, long min, long max )
 						call_gui_num_wipe();
 						return NULL;
 					}
-					gui_n = n;
 				}
 			} else if( sel_n == 1 + figure + MENU_NUM_MIN ){
 				if( flg_ret )
@@ -1753,8 +1750,6 @@ char	*exec_menu_sel_num( long *p, long min, long max )
 
 				n = strtol( num, (char **)NULL, 10 );
 			}
-
-			gui_n = n;
 		}
 	}
 
