@@ -18,9 +18,12 @@ long	randm( long n );
 long	randm_sub( long n );
 bool_t	rate_randm( rate_t rate );
 bool_t	per_randm( long per );
+long	count_randm_rate( rate_t rate );
 long	gui_randm( long n );
 rate_t	modified_rate( rate_t rate, long n );
 bool_t	chk_ver_old( const ver_t *ver, long mjr, long mnr, long pat );
+bool_t	chk_ver_new( const ver_t *ver, long mjr, long mnr, long pat );
+bool_t	chk_ver_new_match( const ver_t *ver, long mjr, long mnr, long pat );
 bool_t	chk_ver_match( const ver_t *ver, long mjr, long mnr, long pat );
 long	str_len_std( const char *s );
 char	*str_nz_cpy( char *dst, const char *src, int len );
@@ -32,6 +35,7 @@ bool_t	chk_flg( unsigned long var, unsigned long flg );
 bool_t	chk_flg_or( unsigned long var, unsigned long flg );
 void	*alloc_mem( long size, bool_t flg_exit );
 void	free_mem( void *p );
+void	check_memory_misc_c( void );
 
 #ifdef __cplusplus
 }
