@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2014 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mmenu.c,v 1.63 2010/08/04 00:40:44 bowkenken Exp $
+* $Id: mmenu.c,v 1.66 2014/01/07 23:40:42 bowkenken Exp $
 ***************************************************************/
 
 #define	MMENU_C
@@ -372,7 +372,7 @@ char	*exec_menu_sel_abl( mbr_t *mbr, abl_kind_t *abl )
 
 char	*cb_menu_sel_abl( menu_t **pp, menu_t **dflt )
 {
-	g_sel_abl = (abl_kind_t)(int)((*pp)->arg);
+	g_sel_abl = (abl_kind_t)(long)((*pp)->arg);
 
 	return NULL;
 }
