@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2014 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mnstr.c,v 1.233 2010/05/13 17:31:58 bowkenken Exp $
+* $Id: mnstr.c,v 1.238 2014/01/07 23:40:42 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -468,7 +468,6 @@ mnstr_t	*make_mnstr_rand( long x, long y, bool_t flg_fix_pos, long dun_lev )
 {
 	mnstr_tab_t	*tab;
 	mnstr_t	*p;
-	long	group;
 	long	i, j;
 
 	if( dun_lev == 0 )
@@ -483,7 +482,6 @@ mnstr_t	*make_mnstr_rand( long x, long y, bool_t flg_fix_pos, long dun_lev )
 
 	p = make_mnstr( x, y, flg_fix_pos, dun_lev, tab->mnstr_kind );
 
-	group = roll_dice( tab->group, TRUE );
 	for( i = 1; i < tab->group; i++ ){
 		long	nx, ny;
 		mnstr_t	*pp;
@@ -554,11 +552,8 @@ mnstr_t	*make_mnstr_alloc(
 )
 {
 	long	i;
-	dun_t	*dun;
 	mnstr_tab_t	*tab;
 
-	dun = get_dun();
-
 	if( p == NULL )
 		return NULL;
 	if( mnstr_kind == MNSTR_KIND_NULL )
@@ -1146,6 +1141,8 @@ mbr_t	*mnstr_mark_mbr_adjoin( mnstr_t *p )
 				p->name );
 		curs_attrset_dflt();
 
+		call_game_sound_play( SOUND_KIND_ACTION_APPEAR, 1 );
+
 		item = get_item( p->x, p->y );
 		if( item != NULL )
 			lost_trgt( item );
@@ -1495,14 +1492,18 @@ bool_t	set_flg_find_mnstr( mnstr_t *p )
 	/* ȯĴ٤ */
 
 	flg_pre_find = chk_flg( p->flg_map, FLG_MAP_CHR_FIND );
+	if( chk_flg( p->flg_map, FLG_MAP_CHR_INVISIBLE ) )
+		flg_pre_find = FALSE;
+
 	p->flg_map &= ~FLG_MAP_CHR_FIND;
-	flg = FLG_NULL;
+	flg = p->flg_map;
 	for( i = 0; i < MBR_MAX_N; i++ ){
 		/* ȯ? */
 		if( chk_find_chr( pty->mbr[i], p ) ){
 			/* ȯޥåסե饰ΩƤ */
 			p->flg_map |= FLG_MAP_CHR_FIND;
-			flg = FLG_MAP_CHR_FIND;
+			p->flg_map &= ~FLG_MAP_CHR_INVISIBLE;
+			flg = p->flg_map;
 
 			break;
 		}
@@ -1526,7 +1527,7 @@ bool_t	set_flg_find_mnstr( mnstr_t *p )
 			if( !clip_pos( x, y ) )
 				continue;
 
-				dun->map.chr.flg[y][x] |= flg;
+				dun->map.chr.flg[y][x] = flg;
 		}
 	}
 
