@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2014 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: request.c,v 1.113 2009/07/02 22:29:45 bowkenken Exp $
+* $Id: request.c,v 1.121 2014/01/07 23:40:42 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -64,6 +64,8 @@
 #define	REQUEST_DUN_MAX_LEV_NORMAL	50
 /* γϰ */
 #define	REQUEST_DUN_RANGE_LEV	2
+/* ã˲äγ */
+#define	REQUEST_DUN_ADD_LEV	1
 
 /* NPC Ψ */
 #define	REQUEST_NPC_CONTRACT_RATE	20
@@ -89,25 +91,25 @@
 ***************************************************************/
 
 #define	REQUEST_RARE_GOODS_GOLD_RATE	((rate_t)2000)
-#define	REQUEST_RARE_GOODS_EXP_RATE	((rate_t)1000)
+#define	REQUEST_RARE_GOODS_EXP_RATE	((rate_t)400)
 
 #define	REQUEST_TAME_MNSTR_GOLD_RATE	((rate_t)1000)
-#define	REQUEST_TAME_MNSTR_EXP_RATE	((rate_t)1000)
+#define	REQUEST_TAME_MNSTR_EXP_RATE	((rate_t)400)
 
 #define	REQUEST_RESCUE_GOLD_RATE	((rate_t)2000)
-#define	REQUEST_RESCUE_EXP_RATE	((rate_t)2000)
+#define	REQUEST_RESCUE_EXP_RATE	((rate_t)800)
 
 #define	REQUEST_TOUR_GUIDE_GOLD_RATE	((rate_t)3000)
-#define	REQUEST_TOUR_GUIDE_EXP_RATE	((rate_t)1000)
+#define	REQUEST_TOUR_GUIDE_EXP_RATE	((rate_t)400)
 
 #define	REQUEST_EXTERMINATE_GOLD_RATE	((rate_t)2000)
-#define	REQUEST_EXTERMINATE_EXP_RATE	((rate_t)2000)
+#define	REQUEST_EXTERMINATE_EXP_RATE	((rate_t)800)
 
 #define	REQUEST_REVENGE_GOLD_RATE	((rate_t)1000)
-#define	REQUEST_REVENGE_EXP_RATE	((rate_t)3000)
+#define	REQUEST_REVENGE_EXP_RATE	((rate_t)1200)
 
 #define	REQUEST_WANTED_CRIMINAL_GOLD_RATE	((rate_t)3000)
-#define	REQUEST_WANTED_CRIMINAL_EXP_RATE	((rate_t)2000)
+#define	REQUEST_WANTED_CRIMINAL_EXP_RATE	((rate_t)800)
 
 #define	REQUEST_PENALTY_RATE	((rate_t)10)
 
@@ -680,6 +682,12 @@ bool_t	make_client( request_t *req, mnstr_kind_t kind, bool_t flg_now )
 	if( owner == NULL )
 		return FALSE;
 
+	if( calc_pet_n() >= PET_MAX_N ){
+		print_msg( FLG_MSG_ERR,
+				MSG_ERR_MENU_REQUEST_CAN_NOT_JOIN_PET );
+		return FALSE;
+	}
+
 	name = MSG_MNSTR_UNKNOWN;
 	sex = FEMALE;
 	npc_dun_lev = 1;
@@ -762,6 +770,8 @@ bool_t	make_client( request_t *req, mnstr_kind_t kind, bool_t flg_now )
 		npc->flg_chr |= FLG_CHR_NO_MARK_MNSTR;
 
 	if( !join_pet( npc ) ){
+		print_msg( FLG_MSG_ERR,
+				MSG_ERR_MENU_REQUEST_CAN_NOT_JOIN_PET );
 		die_chr( npc, FALSE, FALSE, TRUE );
 		return FALSE;
 	}
@@ -831,6 +841,7 @@ long	get_request_dun_max_lev( long dun_min_lev, long dun_max_lev )
 		floor = labs( pty->mbr[i]->dun_max_lev_floor );
 		base = labs( pty->mbr[i]->dun_max_lev_base );
 		lev = max_l( floor, base );
+		lev += REQUEST_DUN_ADD_LEV;
 
 		dun_lev = max_l( dun_lev, lev );
 	}
@@ -1889,12 +1900,12 @@ bool_t	chr_contract_request(
 	/**/
 
 	if( kind == CHR_KIND_MBR ){
+		if( !make_client( req, get_npc_kind_randm(), FALSE ) )
+			return FALSE;
+
 		req->idx_contract_name = -1;
 		req->contract_sex = FEMALE;
 		req->flg_contract_mbr = TRUE;
-
-		if( !make_client( req, get_npc_kind_randm(), FALSE ) )
-			return FALSE;
 	} else if( kind == CHR_KIND_MNSTR ){
 		req->idx_contract_name = n_idx_name;
 		req->contract_sex = sex;
@@ -1967,6 +1978,9 @@ void	chk_find_request_chr( chr_t *chr )
 	case REQUEST_KIND_EXTERMINATE:
 		break;
 	case REQUEST_KIND_REVENGE:
+		if( !chk_watch_request_client( req ) )
+			break;
+
 		msg_fema = MSG_WORDS_REQUEST_REVENGE_FIND_FEMALE;
 		msg_male = MSG_WORDS_REQUEST_REVENGE_FIND_MALE;
 
@@ -2154,7 +2168,9 @@ bool_t	chk_finish_request_join( request_t *req, mnstr_t *npc )
 		return FALSE;
 	}
 
-	make_client( npc->work.request, npc->mnstr_kind, TRUE );
+	if( !make_client( npc->work.request, npc->mnstr_kind, TRUE ) )
+		return FALSE;
+
 	die_chr( npc, FALSE, FALSE, TRUE );
 	finish_request( req );
 
@@ -2196,6 +2212,12 @@ void	chk_finish_request_exterminate(
 			continue;
 		if( g_request[i].mnstr_kind != mnstr_kind )
 			continue;
+		if( (req_kind == REQUEST_KIND_TOUR_GUIDE)
+				|| (req_kind == REQUEST_KIND_REVENGE) ){
+			if( !chk_watch_request_client( &(g_request[i]) ) ){
+				continue;
+			}
+		}
 
 		req = &(g_request[i]);
 		req->mnstr_exterminate_n += add;
@@ -2231,6 +2253,11 @@ bool_t	chk_finish_request_revenge( request_t *req, chr_t *chr )
 	if( cmp_chr( npc, chr ) )
 		return FALSE;
 
+	if( !chk_watch_request_client( req ) ){
+		free_request( req );
+		return FALSE;
+	}
+
 	print_words_win( npc->name, npc->sex.cur,
 			MSG_WORDS_REQUEST_REVENGE_FINISH_FEMALE,
 			MSG_WORDS_REQUEST_REVENGE_FINISH_MALE );
@@ -2406,6 +2433,43 @@ bool_t	give_party_reward_item( item_t *item )
 	return give_party_item( item, TRUE, TRUE );
 }
 
+/***************************************************************
+* 礬ɸݤΤ򸫤Ƥ뤫?
+* request_t *req : 
+* return : Ƥ뤫?
+***************************************************************/
+
+bool_t	chk_watch_request_client( request_t *req )
+{
+	long	i;
+	pet_t	*npc;
+	pet_t	**party_npc = get_party_pet();
+
+	if( req == NULL )
+		return FALSE;
+	if( (req->kind != REQUEST_KIND_TOUR_GUIDE)
+			&& (req->kind != REQUEST_KIND_REVENGE) ){
+		return FALSE;
+	}
+
+	for( i = 0; i < PET_MAX_N; i++ ){
+		npc = party_npc[i];
+
+		if( npc == NULL )
+			continue;
+		if( chk_flg_or( npc->stat,
+				(FLG_STAT_NOT_EXIST | FLG_STAT_DEAD) ) ){
+			continue;
+		}
+		if( npc->work.request != req )
+			continue;
+
+		return TRUE;
+	}
+
+	return FALSE;
+}
+
 /***************************************************************
 * طƤΰ̤
 * request_t *req : 
@@ -2660,6 +2724,24 @@ void	put_request_mnstr( void )
 	}
 }
 
+/***************************************************************
+* 饯 طΥڥå(NPC)?
+* chr_t *chr : ˥塼ꥹ
+* return : ڥå(NPC)?
+***************************************************************/
+
+bool_t	is_client( chr_t *chr )
+{
+	if( chr == NULL )
+		return FALSE;
+	if( !is_pet( chr ) )
+		return FALSE;
+	if( chr->work.request == NULL )
+		return FALSE;
+
+	return TRUE;
+}
+
 /***************************************************************
 * ѡƥƤꥹȤΥ˥塼
 * menu_t **pp : ˥塼ꥹ
@@ -2906,8 +2988,10 @@ char	*cb_menu_request_refresh( menu_t **pp, menu_t **dflt )
 			continue;
 
 		/* СƤϥåפ */
-		if( g_request[i].flg_contract_mbr )
+		if( g_request[i].flg_contract
+				&& g_request[i].flg_contract_mbr ){
 			continue;
+		}
 
 		free_request( &(g_request[i]) );
 	}
@@ -2942,13 +3026,16 @@ bool_t	ask_contract_request( request_t *req )
 	if( ask != ASK_YES )
 		return FALSE;
 
+	if( !chr_contract_request( req, CHR_KIND_MBR, -1, FEMALE ) )
+		return FALSE;
+
 	master_sex = get_npc_sex_shop( SHOP_N_BAR );
 	master_name = get_npc_name_shop( SHOP_N_BAR, master_sex );
 	print_words_win( master_name, master_sex,
 			MSG_WORDS_REQUEST_CONTRACT_FEMALE,
 			MSG_WORDS_REQUEST_CONTRACT_MALE );
 
-	return( chr_contract_request( req, CHR_KIND_MBR, -1, FEMALE ) );
+	return TRUE;
 }
 
 /***************************************************************
