@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2014 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: skill.c,v 1.13 2009/06/01 05:05:04 bowkenken Exp $
+* $Id: skill.c,v 1.18 2014/03/02 02:49:34 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -41,6 +41,7 @@
 
 skill_kind_t	skill_group_tab[SKILL_GROUP_KIND_MAX_N]
 	[SKILL_PER_GROUP_MAX_N + 1];
+check_memory_def( check_memory_skill_c_skill_group_tab )
 
 #include	"skill-tab.h"
 
@@ -104,7 +105,7 @@ void	init_skill_group_tab( void )
 
 rate_t	calc_skill_rate( mbr_t *mbr, skill_kind_t skill_kind )
 {
-	rate_t	rate;
+	rate_t	rate, rate_eq;
 	long	lev;
 	long	mbr_n;
 
@@ -227,6 +228,11 @@ rate_t	calc_skill_rate( mbr_t *mbr, skill_kind_t skill_kind )
 
 	/* SKILL_GROUP_KIND_MISC, */
 	case SKILL_KIND_RUN_AWAY:
+		rate_eq = calc_rate_equip_flg_msg(
+				mbr, ABL_KIND_THI, ABL_KIND_DEX, FALSE );
+		if( rate_eq < _100_PERCENT )
+			break;
+
 		rate = SKILL_RUN_AWAY_BASE_N;
 		rate += SKILL_RUN_AWAY_ADD_N * lev;
 		break;
@@ -1106,3 +1112,13 @@ skill_kind_t	cv_stat_to_skill_stat( flg_stat_t stat )
 
 	return SKILL_KIND_NULL;
 }
+
+/***************************************************************
+* ꡼å
+***************************************************************/
+
+void	check_memory_skill_c( void )
+{
+	check_memory( check_memory_skill_c_skill_group_tab,
+			"skill.c: skill_group_tab" );
+}
