@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2014 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: spell.c,v 1.220 2010/08/18 00:43:35 bowkenken Exp $
+* $Id: spell.c,v 1.226 2014/03/15 00:50:40 bowkenken Exp $
 ***************************************************************/
 
 #define	SPELL_C
@@ -941,6 +941,7 @@ void	chr_cast_spell( chr_t *chr, spell_tab_t *tab, const char *fmt )
 	long	hp, mp;
 	rate_t	resi;
 	bool_t	flg_msg;
+	const char	*inst_spell_name;
 	curs_attr_t	prev_attr;
 
 	if( chr == NULL )
@@ -1018,8 +1019,9 @@ void	chr_cast_spell( chr_t *chr, spell_tab_t *tab, const char *fmt )
 				+ get_lev( chr, ABL_KIND_CHA );
 		resi_div *= SPELL_SHA_RESI_DIV_RATE;
 		resi_div /= _100_PERCENT;
-		if( resi_div < 1 )
-			resi_div = 1;
+		resi_div += _100_PERCENT;
+		if( resi_div < _100_PERCENT )
+			resi_div = _100_PERCENT;
 
 		resi *= _100_PERCENT;
 		resi /= resi_div;
@@ -1043,7 +1045,9 @@ void	chr_cast_spell( chr_t *chr, spell_tab_t *tab, const char *fmt )
 		resi_kind_t	kind;
 		rate_t	d;
 
-		kind = tab->resi;
+		kind = tab->resi_vfx;
+		if( kind >= RESI_KIND_MAX_N )
+			kind = tab->resi;
 
 		if( kind < 0 )
 			return;
@@ -1090,12 +1094,27 @@ void	chr_cast_spell( chr_t *chr, spell_tab_t *tab, const char *fmt )
 		flg_msg = FALSE;
 	} while( 0 );
 
+	inst_spell_name = NULL;
+	if( tab->abl == ABL_KIND_BAR ){
+		spell_kind_t	kind;
+
+		kind = get_inst_spell_kind( (mbr_t *)chr );
+		if( kind != SPELL_KIND_NULL ){
+			inst_spell_name = get_spell_name( kind );
+		}
+	}
+
 	if( flg_msg ){
 		play_sound_spell( chr, tab->kind );
 
 		if( fmt == NULL ){
 			print_msg( FLG_NULL, MSG_SPELL,
 					chr->name, tab->name );
+			if( inst_spell_name != NULL ){
+				print_msg( FLG_NULL, MSG_SPELL,
+						chr->name,
+						inst_spell_name );
+			}
 		} else {
 			print_msg( FLG_NULL, fmt,
 					chr->name );
@@ -3163,6 +3182,55 @@ bool_t	chk_bar_limit_lev( chr_t *chr )
 
 /**/
 
+chr_kind_t	get_inst_spell_chr_kind( chr_t *chr, spell_kind_t kind )
+{
+	switch( kind ){
+	default:
+		break;
+	case SPELL_KIND_SONG_CURE_HP:
+	case SPELL_KIND_SONG_CURE_MP:
+	case SPELL_KIND_SONG_SHARPNESS:
+	case SPELL_KIND_SONG_STRENGTH:
+	case SPELL_KIND_SONG_QUICKNESS:
+	case SPELL_KIND_SONG_BRAINY:
+	case SPELL_KIND_SONG_WISE:
+	case SPELL_KIND_SONG_ATTRACTIVE:
+	case SPELL_KIND_SONG_RESI_STAT_STONE:
+	case SPELL_KIND_SONG_RESI_STAT_PARALYZE:
+	case SPELL_KIND_SONG_RESI_STAT_POISON:
+	case SPELL_KIND_SONG_RESI_STAT_CONFUSION:
+	case SPELL_KIND_SONG_RESI_STAT_BLIND:
+	case SPELL_KIND_SONG_RESI_STAT_SLEEP:
+	case SPELL_KIND_SONG_RESI_STAT_SILENCE:
+	case SPELL_KIND_SONG_RESI_STAT_FEAR:
+	case SPELL_KIND_SONG_RESI_STAT_HALLUCINATION:
+	case SPELL_KIND_SONG_RESI_STAT_CHARM:
+	case SPELL_KIND_SONG_RESI_STAT_DRUNK:
+		/* ٱ */
+		if( is_mbr( chr ) || is_pet( chr ) )
+			return CHR_KIND_MBR;
+		else
+			return CHR_KIND_MNSTR;
+		break;
+	case SPELL_KIND_SONG_DULLNESS:
+	case SPELL_KIND_SONG_WEAKNESS:
+	case SPELL_KIND_SONG_SLOWNESS:
+	case SPELL_KIND_SONG_BRAINLESS:
+	case SPELL_KIND_SONG_FOOLISH:
+	case SPELL_KIND_SONG_UNATTRACTIVE:
+		/* ˸ */
+		if( is_mbr( chr ) || is_pet( chr ) )
+			return CHR_KIND_MNSTR;
+		else
+			return CHR_KIND_MBR;
+		break;
+	}
+
+	return CHR_KIND_NULL;
+}
+
+/**/
+
 bool_t	chk_can_chr_cast_stat( chr_t *chr )
 {
 	if( chr == NULL )
