@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2014 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: tmenu.c,v 1.166 2010/08/31 11:21:32 bowkenken Exp $
+* $Id: tmenu.c,v 1.169 2014/01/07 23:40:42 bowkenken Exp $
 ***************************************************************/
 
 #define	TMENU_C
@@ -763,14 +763,11 @@ char	*menu_shop( shop_n_t shop_n, mbr_t *mbr, char *str_goto )
 	long	i, j, k;
 	long	key_n;
 	item_t	*art_head, *art;
-	long	ls_art_n, art_n;
+	long	ls_art_n;
 	static item_t	*ls_art[ARTICLE_MAX_N];
 	char	*buy_sale;
-	party_t	*pty;
 	long	len, max_len;
 
-	pty = get_party();
-
 	if( mbr == NULL )
 		return STR_MENU_ERR;
 
@@ -803,7 +800,6 @@ char	*menu_shop( shop_n_t shop_n, mbr_t *mbr, char *str_goto )
 
 	max_len = 0;
 	ls_art_n = 0;
-	art_n = 0;
 	key_n = 0;
 	page = 0;
 	for( art = art_head;
