@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2014 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: town.c,v 1.162 2010/08/05 00:08:46 bowkenken Exp $
+* $Id: town.c,v 1.166 2014/01/07 23:40:42 bowkenken Exp $
 ***************************************************************/
 
 #define	TOWN_C
@@ -522,7 +522,6 @@ bool_t	set_town_ptn_map( town_ptn_t *ptn, char *s, long y )
 
 bool_t	trans_town_ptn( town_ptn_t *dst, town_ptn_t *src )
 {
-	town_ptn_col_tab_t	*col_tab;
 	long	col_tab_max_n;
 	long	x, y;
 
@@ -534,7 +533,6 @@ bool_t	trans_town_ptn( town_ptn_t *dst, town_ptn_t *src )
 	if( src->col_str_len == 2 )
 		return FALSE;
 
-	col_tab = get_town_ptn_col_tab();
 	col_tab_max_n = get_town_ptn_col_tab_max_n();
 
 	if( col_tab_max_n > TOWN_PTN_COL_MAX_N )
@@ -1346,12 +1344,10 @@ bool_t	chk_shop_face_ls( void )
 
 bool_t	appear_party_town( void )
 {
-	dun_t *dun;
 	party_t	*pty;
 	long	n;
 	long	x, y;
 
-	dun = get_dun();
 	pty = get_party();
 
 	for( n = 0; n < MBR_MAX_N; n++ ){
@@ -1469,16 +1465,12 @@ bool_t	open_door_shop( long n )
 
 bool_t	enter_shop( void )
 {
-	dun_t	*dun;
 	party_t	*pty;
-	pet_t	**pet;
 	char	face_mnr;
 	long	dr_n;
 	shop_n_t	shop_n;
 
-	dun = get_dun();
 	pty = get_party();
-	pet = get_party_pet();
 
 	set_flg_exit_shop( TRUE );
 
@@ -1641,6 +1633,7 @@ void	party_exit_shop( long dr_n )
 		add_turn( SHOP_ADD_TURN_N );
 
 	change_scene( SCENE_N_TOWN );
+	set_cur_shop_n( SHOP_N_NULL );
 
 	srandm( seed );
 }
@@ -3397,10 +3390,8 @@ bool_t	chk_discount_day( void )
 
 bool_t	chk_discount_turn()
 {
-	long	day;
 	long	turn;
 
-	day = get_game_day();
 	turn = get_turn();
 
 	if( g_discount_queue.shop_n == SHOP_N_NULL )
@@ -3777,6 +3768,21 @@ void	dec_discount_queue( long n )
 		g_discount_queue.n = 0;
 }
 
+/***************************************************************
+* ѡƥŹ˵뤫Ĵ٤
+***************************************************************/
+
+bool_t	chk_party_in_shop( void )
+{
+	if( get_cur_shop_n() != SHOP_N_NULL )
+		return TRUE;
+
+	if( get_scene() == SCENE_N_SHOP )
+		return TRUE;
+
+	return FALSE;
+}
+
 /***************************************************************
 * Źֹ椫ŹΥɥѴ
 * shop_n_t n : Źֹ
